@@ -16,13 +16,14 @@ warning_msg = "{} CLI tools are not available. This is most "\
 try:
     from sermos.cli.deploy import deployment
     collection.append(deployment)
-except ImportError:
+except ImportError as e:
     logger.warning(warning_msg.format("Deployment"))
+    logger.warning(f"{e}")
 
 try:
     from sermos.cli.config_server import config_server
     collection.append(config_server)
-except ImportError:
+except ImportError as e:
     logger.warning(warning_msg.format("Configuration Server"))
-
+    logger.warning(f"{e}")
 sermos = click.CommandCollection(sources=collection)
