@@ -72,22 +72,6 @@ class EnvironmentVariableSchema(ExcludeUnknownSchema):
                           description="Environment variable value.",
                           example="my special value")
 
-    @pre_load
-    def replace_null_values(self, item, **kwargs):
-        """ Environment variables are often secrets and therefore should not
-            be committed to the sermos.yaml file. Instead, they should be
-            templated with ${ENV_VAR_NAME} and injected into the file only
-            in memory during deployments, etc.
-
-            The Sermos application will use the sermos.yaml file for other
-            configuration pieces that do not require the environment variables,
-            therefore we add 'unset' as the value to any null values in order
-            for the schema to pass the load step as being non-null.
-        """
-        item["value"] = item["value"]\
-            if item.get("value", None) is not None else "unset"
-        return item
-
 
 class EnvironmentVariablesSchema(Schema):
     """ Multiple environment variables (plural)
@@ -514,7 +498,7 @@ class YamlPatternConstructor():
             # which would have 'split' above
             if len(env_var_name_split) > 1:
                 return ":".join(env_var_name_split[1:])
-            return None  # Return None if not in environ nor default
+            return 'unset'  # Return 'unset' if not in environ nor default
         return env_var
 
     def add_constructor(self):
